==> anjuta-2.1.0.tar.bz2: anjuta-2.1.0/libanjuta/interfaces/libanjuta-iface-marshallers.h <==

#ifndef __libanjuta_iface_cclosure_marshal_MARSHAL_H__
#define __libanjuta_iface_cclosure_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:BOOLEAN (./libanjuta-iface-marshallers.list:1) */
#define libanjuta_iface_cclosure_marshal_VOID__BOOLEAN	g_cclosure_marshal_VOID__BOOLEAN

/* VOID:BOOLEAN,INT (./libanjuta-iface-marshallers.list:2) */
extern void libanjuta_iface_cclosure_marshal_VOID__BOOLEAN_INT (GClosure     *closure,
                                                                GValue       *return_value,
                                                                guint         n_param_values,
                                                                const GValue *param_values,
                                                                gpointer      invocation_hint,
                                                                gpointer      marshal_data);

/* VOID:ENUM (./libanjuta-iface-marshallers.list:3) */
#define libanjuta_iface_cclosure_marshal_VOID__ENUM	g_cclosure_marshal_VOID__ENUM

/* VOID:INT (./libanjuta-iface-marshallers.list:4) */
#define libanjuta_iface_cclosure_marshal_VOID__INT	g_cclosure_marshal_VOID__INT

/* VOID:INT,BOOLEAN,INT,INT,STRING (./libanjuta-iface-marshallers.list:5) */
extern void libanjuta_iface_cclosure_marshal_VOID__INT_BOOLEAN_INT_INT_STRING (GClosure     *closure,
                                                                               GValue       *return_value,
                                                                               guint         n_param_values,
                                                                               const GValue *param_values,
                                                                               gpointer      invocation_hint,
                                                                               gpointer      marshal_data);

/* VOID:INT,CHAR (./libanjuta-iface-marshallers.list:6) */
extern void libanjuta_iface_cclosure_marshal_VOID__INT_CHAR (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
                                                             const GValue *param_values,
                                                             gpointer      invocation_hint,
                                                             gpointer      marshal_data);

/* VOID:STRING (./libanjuta-iface-marshallers.list:7) */
#define libanjuta_iface_cclosure_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING

/* VOID:STRING,UINT,STRING (./libanjuta-iface-marshallers.list:8) */
extern void libanjuta_iface_cclosure_marshal_VOID__STRING_UINT_STRING (GClosure     *closure,
                                                                       GValue       *return_value,
                                                                       guint         n_param_values,
                                                                       const GValue *param_values,
                                                                       gpointer      invocation_hint,
                                                                       gpointer      marshal_data);

/* VOID:UINT (./libanjuta-iface-marshallers.list:9) */
#define libanjuta_iface_cclosure_marshal_VOID__UINT	g_cclosure_marshal_VOID__UINT

/* VOID:VOID (./libanjuta-iface-marshallers.list:10) */
#define libanjuta_iface_cclosure_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

G_END_DECLS

#endif /* __libanjuta_iface_cclosure_marshal_MARSHAL_H__ */

==> anjuta-2.1.1.tar.bz2: anjuta-2.1.1/libanjuta/interfaces/libanjuta-iface-marshallers.h <==

#ifndef __libanjuta_iface_cclosure_marshal_MARSHAL_H__
#define __libanjuta_iface_cclosure_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:BOOLEAN (./libanjuta-iface-marshallers.list:1) */
#define libanjuta_iface_cclosure_marshal_VOID__BOOLEAN	g_cclosure_marshal_VOID__BOOLEAN

/* VOID:BOOLEAN,INT (./libanjuta-iface-marshallers.list:2) */
extern void libanjuta_iface_cclosure_marshal_VOID__BOOLEAN_INT (GClosure     *closure,
                                                                GValue       *return_value,
                                                                guint         n_param_values,
                                                                const GValue *param_values,
                                                                gpointer      invocation_hint,
                                                                gpointer      marshal_data);

/* VOID:ENUM (./libanjuta-iface-marshallers.list:3) */
#define libanjuta_iface_cclosure_marshal_VOID__ENUM	g_cclosure_marshal_VOID__ENUM

/* VOID:INT (./libanjuta-iface-marshallers.list:4) */
#define libanjuta_iface_cclosure_marshal_VOID__INT	g_cclosure_marshal_VOID__INT

/* VOID:INT,BOOLEAN,INT,INT,STRING (./libanjuta-iface-marshallers.list:5) */
extern void libanjuta_iface_cclosure_marshal_VOID__INT_BOOLEAN_INT_INT_STRING (GClosure     *closure,
                                                                               GValue       *return_value,
                                                                               guint         n_param_values,
                                                                               const GValue *param_values,
                                                                               gpointer      invocation_hint,
                                                                               gpointer      marshal_data);

/* VOID:INT,CHAR (./libanjuta-iface-marshallers.list:6) */
extern void libanjuta_iface_cclosure_marshal_VOID__INT_CHAR (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
                                                             const GValue *param_values,
                                                             gpointer      invocation_hint,
                                                             gpointer      marshal_data);

/* VOID:STRING (./libanjuta-iface-marshallers.list:7) */
#define libanjuta_iface_cclosure_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING

/* VOID:STRING,UINT,UINT (./libanjuta-iface-marshallers.list:8) */
extern void libanjuta_iface_cclosure_marshal_VOID__STRING_UINT_UINT (GClosure     *closure,
                                                                     GValue       *return_value,
                                                                     guint         n_param_values,
                                                                     const GValue *param_values,
                                                                     gpointer      invocation_hint,
                                                                     gpointer      marshal_data);

/* VOID:UINT (./libanjuta-iface-marshallers.list:9) */
#define libanjuta_iface_cclosure_marshal_VOID__UINT	g_cclosure_marshal_VOID__UINT

/* VOID:VOID (./libanjuta-iface-marshallers.list:10) */
#define libanjuta_iface_cclosure_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

G_END_DECLS

#endif /* __libanjuta_iface_cclosure_marshal_MARSHAL_H__ */
